@@ -33,13 +33,13 @@
 #include "../Dialogs/krdialogs.h"
 
 #include <tqgroupbox.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqlayout.h>
 #include <tqlabel.h>
 #include <tqbuttongroup.h>
 #include <tqfile.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <time.h>
 #include <kiconloader.h>
 
@@ -107,7 +107,7 @@ AdvancedFilter::AdvancedFilter( FilterTabs *tabs, TQWidget *parent, const char *
 
   // Options for date
 
-  TQPixmap iconDate = krLoader->loadIcon( "date", KIcon::Toolbar, 16 );
+  TQPixmap iconDate = krLoader->loadIcon( "date", TDEIcon::Toolbar, 16 );
 
   TQButtonGroup *dateGroup = new TQButtonGroup( this, "dateGroup" );
   dateGroup->setTitle( i18n( "Date" ) );
@@ -422,14 +422,14 @@ void AdvancedFilter::notModifiedAfterSetDate()
 
 void AdvancedFilter::changeDate(TQLineEdit *p) {
   // check if the current date is valid
-  TQDate d = KGlobal::locale()->readDate(p->text());
+  TQDate d = TDEGlobal::locale()->readDate(p->text());
   if (!d.isValid()) d = TQDate::currentDate();
 
   KRGetDate *gd = new KRGetDate(d, this);
   d = gd->getDate();
   // if a user pressed ESC or closed the dialog, we'll return an invalid date
   if (d.isValid())
-    p->setText(KGlobal::locale()->formatDate(d, true));
+    p->setText(TDEGlobal::locale()->formatDate(d, true));
   delete gd;
 }
 
@@ -478,7 +478,7 @@ void AdvancedFilter::invalidDateMessage(TQLineEdit *p)
 
 bool AdvancedFilter::fillQuery( KRQuery *query )
 {
-  KIO::filesize_t minSize = 0, maxSize = 0;
+  TDEIO::filesize_t minSize = 0, maxSize = 0;
 
   // size calculations ////////////////////////////////////////////////
   if ( biggerThanEnabled->isChecked() &&
@@ -517,9 +517,9 @@ bool AdvancedFilter::fillQuery( KRQuery *query )
     if ( !(modifiedBetweenData1->text().simplifyWhiteSpace().isEmpty() &&
           modifiedBetweenData2->text().simplifyWhiteSpace().isEmpty()) ) {
       // check if date is valid
-      TQDate d1 = KGlobal::locale()->readDate(modifiedBetweenData1->text());
+      TQDate d1 = TDEGlobal::locale()->readDate(modifiedBetweenData1->text());
       if (!d1.isValid()) { invalidDateMessage(modifiedBetweenData1); return false; }
-      TQDate d2 = KGlobal::locale()->readDate(modifiedBetweenData2->text());
+      TQDate d2 = TDEGlobal::locale()->readDate(modifiedBetweenData2->text());
       if (!d2.isValid()) { invalidDateMessage(modifiedBetweenData2); return false; }
 
       if (d1 > d2) {
@@ -538,7 +538,7 @@ bool AdvancedFilter::fillQuery( KRQuery *query )
     }
   } else if (notModifiedAfterEnabled->isChecked()) {
     if ( !notModifiedAfterData->text().simplifyWhiteSpace().isEmpty() ) {
-      TQDate d = KGlobal::locale()->readDate(notModifiedAfterData->text());
+      TQDate d = TDEGlobal::locale()->readDate(notModifiedAfterData->text());
       if (!d.isValid()) { invalidDateMessage(notModifiedAfterData); return false; }
       time_t olderTime;
       qdate2time_t(&olderTime, d, false);
