@@ -30,7 +30,7 @@
 
 #include "konfiguratoritems.h"
 #include "../krusader.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqpainter.h>
 #include <tqpen.h>
 #include <tqcolordialog.h>
@@ -351,7 +351,7 @@ KonfiguratorURLRequester::KonfiguratorURLRequester( TQString cls, TQString name,
 
   connect( TQT_TQOBJECT(this), TQT_SIGNAL( textChanged(const TQString &) ), ext, TQT_SLOT( setChanged() ) );
 
-  button()->setIconSet( SmallIcon( "fileopen" ) );
+  button()->setIconSet( SmallIcon( "document-open" ) );
   loadInitialValue();
 }
 
@@ -397,7 +397,7 @@ KonfiguratorFontChooser::KonfiguratorFontChooser( TQString cls, TQString name, T
 
   connect( pToolButton, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(this), TQT_SLOT( slotBrowseFont() ) );
 
-  pToolButton->setIconSet( SmallIcon( "fileopen" ) );
+  pToolButton->setIconSet( SmallIcon( "document-open" ) );
 
   loadInitialValue();
 }
@@ -436,7 +436,7 @@ void KonfiguratorFontChooser::slotSetDefaults(TQObject *)
 
 void KonfiguratorFontChooser::slotBrowseFont()
 {
-  int ok=KFontDialog::getFont( font );
+  int ok=TDEFontDialog::getFont( font );
   if (ok!=1) return;  // cancelled by the user
   ext->setChanged();
   setFont();
